@@ -1,5 +1,5 @@
 from .load_components import TextDescriptives
-from .components import DescriptiveStatistics, Readability, DependencyDistance
+from .components import DescriptiveStatistics, Readability, DependencyDistance, POSStatistics
 from .dataframe_extract import (
     extract_df,
     extract_dict,
